#ifndef _FRAME_RENDER
#define _FRAME_RENDER

#include "../global.h"
#include "../RGBImage.h"
#include "PixelCallback.h"

void RenderFrame(RGBImage buffer, const PixelCallback** callbacks, usize sizeCallbacks);

#endif /* _FRAME_RENDER */
